#
# spec file for package python-helpdev
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-helpdev
Version:        0.7.1
Release:        3.1
Summary:        HelpDev - Extracts information about the Python environment easily
License:        CC-BY-4.0 AND MIT
Group:          Development/Languages/Python
URL:            https://gitlab.com/dpizetta/helpdev
Source0:        https://gitlab.com/dpizetta/helpdev/-/archive/v%{version}/helpdev-v%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata
Requires:       python-psutil >= 5.4.8
Requires(post): alts
Requires(postun): alts
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module psutil >= 5.4.8}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
HelpDev - Extracts information about the Python environment easily.

%prep
%setup -q -n helpdev-v%{version}
sed -i '1{\,^#!%{_bindir}/env python,d}' helpdev/*.py
sed -i -e "s/psutil>=5.6/psutil>=5.4.8/" setup.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/helpdev
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
#test_check_python_packages needs the binary
%pytest -k 'not test_check_python_packages'

%post
%python_install_alternative helpdev

%postun
%python_uninstall_alternative helpdev

%files %{python_files}
%doc README.rst
%python_alternative %{_bindir}/helpdev
%{python_sitelib}/helpdev
%{python_sitelib}/helpdev-%{version}*-info

%changelog
* Tue May 27 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Tue May 26 2020 Antonio Larrosa <alarrosa@suse.com>
- python-psutil is only used to call its "swap_memory" and
  "virtual_memory" functions, so we reduced the required version
  from 5.6 to 5.4.8 so we can build packages for SLE/Leap.
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon May 18 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to version 0.7.1 (fixes issue reported in boo#1135733 #c4):
  * Fix pipeline, doc8 linting ignores D001, line too long
  * Add customize function, part of #1
  * Change _filter to filter_packages and make it public
  * Improve filter_package explanation
  * Improve docs
  * Add check_qt() function
  * Add check_numbers() function
  * Enhance help from command line parser
  * Enhance command line order
  * Correct mispelling errors
  * Remove importlib_metadata for Python 3.8+, incoporated into std lib, MR#2
  * Add MANIFEST.in, part of #9
  * Improve internal code and linting
  * Remove support for Python 2.7 and 3.4, closes #8
- There's no 0.7.0 release by upstream.
- Remove patch already included by upstream:
  * python38.patch
* Sun Mar  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Use proper name for importlib-metadata
* Tue Jan 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball to get tests and license
- Run the tests
* Tue Jan 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec cleaner
- Add patch to work with python 3.8:
  * python38.patch
* Sat Jan 25 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- initial version for package
